==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Complete/Gui/Resources/translations/Complete_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Kompletan</translation>
    </message>
    <message>
      <source>Constraint Axle...</source>
      <translation>Ograničena osovina...</translation>
    </message>
    <message>
      <source>set a axle constraint between two objects</source>
      <translation>postaviti ograničenja osovine između dva objekta</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Samoprovjera ...</translation>
    </message>
    <message>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Izvrši samoprovjeru i vidi da li program radi ispravno</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Dr&amp;awing</source>
      <translation>Cr&amp;tež</translation>
    </message>
    <message>
      <source>S&amp;ketch</source>
      <translation>S&amp;kica</translation>
    </message>
    <message>
      <source>&amp;Raytracing</source>
      <translation>Metode trasiranja putem zrake</translation>
    </message>
    <message>
      <source>&amp;Drafting</source>
      <translation>&amp;Skica</translation>
    </message>
    <message>
      <source>Sketch based</source>
      <translation>Na temelju skice</translation>
    </message>
    <message>
      <source>Primitives</source>
      <translation>Primitivi</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation>Parametarski</translation>
    </message>
    <message>
      <source>Object appearence</source>
      <translation>Izgled objekta</translation>
    </message>
    <message>
      <source>Wire Tools</source>
      <translation>Alati žice</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Complete/Gui/Resources/translations/Complete_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hr" sourcelanguage="en">
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Kompletan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Constraint Axle...</source>
      <translation>Ograničena osovina...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set a axle constraint between two objects</source>
      <translation>postaviti ograničenja osovine između dva objekta</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Samoprovjera ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Izvrši samoprovjeru i vidi da li program radi ispravno</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location line="-9"/>
      <source>Dr&amp;awing</source>
      <translation>Cr&amp;tež</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>S&amp;ketch</source>
      <translation>S&amp;kica</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>&amp;Raytracing</source>
      <translation>Metode trasiranja putem zrake</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Drafting</source>
      <translation>&amp;Skica</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Sketch based</source>
      <translation>Na temelju skice</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Primitives</source>
      <translation>Primitivi</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation type="obsolete">Parametarski</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Object appearence</source>
      <translation>Izgled objekta</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Wire Tools</source>
      <translation>Alati žice</translation>
    </message>
  </context>
</TS>
